@@ -23,6 +23,7 @@ import (
 	"errors"
 	"fmt"
 	"net/url"
+	"strings"
 	"time"
 
 	"github.com/snapcore/snapd/snap"
@@ -123,6 +124,9 @@ func (client *Client) List(names []string, opts *ListOptions) ([]*Snap, error) {
 	if opts.All {
 		q.Add("select", "all")
 	}
+	if len(names) > 0 {
+		q.Add("snaps", strings.Join(names, ","))
+	}
 
 	snaps, _, err := client.snapsFromPath("/v2/snaps", q)
 	if err != nil {
@@ -133,23 +137,7 @@ func (client *Client) List(names []string, opts *ListOptions) ([]*Snap, error) {
 		return nil, ErrNoSnapsInstalled
 	}
 
-	if len(names) == 0 {
-		return snaps, nil
-	}
-
-	wanted := make(map[string]bool, len(names))
-	for _, name := range names {
-		wanted[name] = true
-	}
-
-	var result []*Snap
-	for _, snap := range snaps {
-		if wanted[snap.Name] {
-			result = append(result, snap)
-		}
-	}
-
-	return result, nil
+	return snaps, nil
 }
 
 // Sections returns the list of existing snap sections in the store
