@@ -116,13 +116,9 @@ static void setup_private_mount(const char *snap_name)
 		die("cannot change directory to '/'");
 
 	// MS_BIND is there from linux 2.4
-	if (mount(tmpdir, "/tmp", NULL, MS_BIND, NULL) != 0) {
-		die("cannot bind mount private /tmp");
-	}
+	sc_do_mount(tmpdir, "/tmp", NULL, MS_BIND, NULL);
 	// MS_PRIVATE needs linux > 2.6.11
-	if (mount("none", "/tmp", NULL, MS_PRIVATE, NULL) != 0) {
-		die("cannot change sharing on /tmp to make it private");
-	}
+	sc_do_mount("none", "/tmp", NULL, MS_PRIVATE, NULL);
 	// do the chown after the bind mount to avoid potential shenanigans
 	if (chown("/tmp/", uid, gid) < 0) {
 		die("cannot change ownership of /tmp");
@@ -168,14 +164,9 @@ static void setup_private_pts()
 	}
 	// Since multi-instance, use ptmxmode=0666. The other options are
 	// copied from /etc/default/devpts
-	if (mount("devpts", "/dev/pts", "devpts", MS_MGC_VAL,
-		  "newinstance,ptmxmode=0666,mode=0620,gid=5")) {
-		die("cannot mount a new instance of /dev/pts");
-	}
-
-	if (mount("/dev/pts/ptmx", "/dev/ptmx", "none", MS_BIND, 0)) {
-		die("cannot mount /dev/pts/ptmx at /dev/ptmx'");
-	}
+	sc_do_mount("devpts", "/dev/pts", "devpts", MS_MGC_VAL,
+		    "newinstance,ptmxmode=0666,mode=0620,gid=5");
+	sc_do_mount("/dev/pts/ptmx", "/dev/ptmx", "none", MS_BIND, 0);
 }
 
 /*
@@ -236,10 +227,7 @@ static void sc_setup_mount_profiles(const char *snap_name)
 		if (hasmntopt(m, "rw") != NULL) {
 			flags &= ~MS_RDONLY;
 		}
-		if (mount(m->mnt_fsname, m->mnt_dir, NULL, flags, NULL) != 0) {
-			die("cannot mount %s at %s with options %s",
-			    m->mnt_fsname, m->mnt_dir, m->mnt_opts);
-		}
+		sc_do_mount(m->mnt_fsname, m->mnt_dir, NULL, flags, NULL);
 	}
 }
 
@@ -303,30 +291,18 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 	debug("scratch directory for constructing namespace: %s", scratch_dir);
 	// Make the root filesystem recursively shared. This way propagation events
 	// will be shared with main mount namespace.
-	debug("performing operation: mount --make-rshared /");
-	if (mount("none", "/", NULL, MS_REC | MS_SHARED, NULL) < 0) {
-		die("cannot perform operation: mount --make-rshared /");
-	}
+	sc_do_mount("none", "/", NULL, MS_REC | MS_SHARED, NULL);
 	// Bind mount the temporary scratch directory for root filesystem over
 	// itself so that it is a mount point. This is done so that it can become
 	// unbindable as explained below.
-	debug("performing operation: mount --bind %s %s", scratch_dir,
-	      scratch_dir);
-	if (mount(scratch_dir, scratch_dir, NULL, MS_BIND, NULL) < 0) {
-		die("cannot perform operation: mount --bind %s %s", scratch_dir,
-		    scratch_dir);
-	}
+	sc_do_mount(scratch_dir, scratch_dir, NULL, MS_BIND, NULL);
 	// Make the scratch directory unbindable.
 	//
 	// This is necessary as otherwise a mount loop can occur and the kernel
 	// would crash. The term unbindable simply states that it cannot be bind
 	// mounted anywhere. When we construct recursive bind mounts below this
 	// guarantees that this directory will not be replicated anywhere.
-	debug("performing operation: mount --make-unbindable %s", scratch_dir);
-	if (mount("none", scratch_dir, NULL, MS_UNBINDABLE, NULL) < 0) {
-		die("cannot perform operation: mount --make-unbindable %s",
-		    scratch_dir);
-	}
+	sc_do_mount("none", scratch_dir, NULL, MS_UNBINDABLE, NULL);
 	// Recursively bind mount desired root filesystem directory over the
 	// scratch directory. This puts the initial content into the scratch space
 	// and serves as a foundation for all subsequent operations below.
@@ -335,22 +311,13 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 	// filesystem of a core system (aka all-snap) or the core snap on a classic
 	// system. In the former case we need recursive bind mounts to accurately
 	// replicate the state of the root filesystem into the scratch directory.
-	debug("performing operation: mount --rbind %s %s", config->rootfs_dir,
-	      scratch_dir);
-	if (mount(config->rootfs_dir, scratch_dir, NULL, MS_REC | MS_BIND, NULL)
-	    < 0) {
-		die("cannot perform operation: mount --rbind %s %s",
-		    config->rootfs_dir, scratch_dir);
-	}
+	sc_do_mount(config->rootfs_dir, scratch_dir, NULL, MS_REC | MS_BIND,
+		    NULL);
 	// Make the scratch directory recursively private. Nothing done there will
 	// be shared with any peer group, This effectively detaches us from the
 	// original namespace and coupled with pivot_root below serves as the
 	// foundation of the mount sandbox.
-	debug("performing operation: mount --make-rslave %s", scratch_dir);
-	if (mount("none", scratch_dir, NULL, MS_REC | MS_SLAVE, NULL) < 0) {
-		die("cannot perform operation: mount --make-rslave %s",
-		    scratch_dir);
-	}
+	sc_do_mount("none", scratch_dir, NULL, MS_REC | MS_SLAVE, NULL);
 	// Bind mount certain directories from the host filesystem to the scratch
 	// directory. By default mount events will propagate in both into and out
 	// of the peer group. This way the running application can alter any global
@@ -364,22 +331,12 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 		}
 		sc_must_snprintf(dst, sizeof dst, "%s/%s", scratch_dir,
 				 mnt->path);
-		debug("performing operation: mount --rbind %s %s", mnt->path,
-		      dst);
-		if (mount(mnt->path, dst, NULL, MS_REC | MS_BIND, NULL) < 0) {
-			die("cannot perform operation: mount --rbind %s %s",
-			    mnt->path, dst);
-		}
+		sc_do_mount(mnt->path, dst, NULL, MS_REC | MS_BIND, NULL);
 		if (!mnt->is_bidirectional) {
 			// Mount events will only propagate inwards to the namespace. This
 			// way the running application cannot alter any global state apart
 			// from that of its own snap.
-			debug("performing operation: mount --make-rslave %s",
-			      dst);
-			if (mount("none", dst, NULL, MS_REC | MS_SLAVE, NULL) !=
-			    0) {
-				die("cannot perform operation: mount --make-rslave %s", dst);
-			}
+			sc_do_mount("none", dst, NULL, MS_REC | MS_SLAVE, NULL);
 		}
 	}
 	// Since we mounted /etc from the host filesystem to the scratch directory,
@@ -394,16 +351,8 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 				 etc_alternatives);
 		sc_must_snprintf(dst, sizeof dst, "%s%s", scratch_dir,
 				 etc_alternatives);
-		debug("performing operation: mount --bind %s %s", src, dst);
-		if (mount(src, dst, NULL, MS_BIND, NULL) != 0) {
-			die("cannot perform operation: mount --bind %s %s", src,
-			    dst);
-		}
-		debug("performing operation: mount --make-slave %s", dst);
-		if (mount("none", dst, NULL, MS_SLAVE, NULL) != 0) {
-			die("cannot perform operation: mount --make-slave %s",
-			    dst);
-		}
+		sc_do_mount(src, dst, NULL, MS_BIND, NULL);
+		sc_do_mount("none", dst, NULL, MS_SLAVE, NULL);
 	}
 	// Bind mount the directory where all snaps are mounted. The location of
 	// the this directory on the host filesystem may not match the location in
@@ -411,16 +360,9 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 	// directory is always /snap. On the host it is a build-time configuration
 	// option stored in SNAP_MOUNT_DIR.
 	sc_must_snprintf(dst, sizeof dst, "%s/snap", scratch_dir);
-	debug("performing operation: mount --rbind %s %s", SNAP_MOUNT_DIR, dst);
-	if (mount(SNAP_MOUNT_DIR, dst, NULL, MS_BIND | MS_REC | MS_SLAVE, NULL)
-	    < 0) {
-		die("cannot perform operation: mount --rbind -o slave %s %s",
-		    SNAP_MOUNT_DIR, dst);
-	}
-	debug("performing operation: mount --make-rslave %s", dst);
-	if (mount("none", dst, NULL, MS_REC | MS_SLAVE, NULL) < 0) {
-		die("cannot perform operation: mount --make-rslave %s", dst);
-	}
+	sc_do_mount(SNAP_MOUNT_DIR, dst, NULL, MS_BIND | MS_REC | MS_SLAVE,
+		    NULL);
+	sc_do_mount("none", dst, NULL, MS_REC | MS_SLAVE, NULL);
 	// Create the hostfs directory if one is missing. This directory is a part
 	// of packaging now so perhaps this code can be removed later.
 	if (access(SC_HOSTFS_DIR, F_OK) != 0) {
@@ -449,14 +391,8 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 	// has a number of undocumented requirements and one of them is that the
 	// "put_old" directory (the second argument) cannot be shared in any way.
 	sc_must_snprintf(dst, sizeof dst, "%s/%s", scratch_dir, SC_HOSTFS_DIR);
-	debug("performing operation: mount --bind %s %s", dst, dst);
-	if (mount(dst, dst, NULL, MS_BIND, NULL) < 0) {
-		die("cannot perform operation: mount --bind %s %s", dst, dst);
-	}
-	debug("performing operation: mount --make-private %s", dst);
-	if (mount("none", dst, NULL, MS_PRIVATE, NULL) < 0) {
-		die("cannot perform operation: mount --make-private %s", dst);
-	}
+	sc_do_mount(dst, dst, NULL, MS_BIND, NULL);
+	sc_do_mount("none", dst, NULL, MS_PRIVATE, NULL);
 	// On classic mount the nvidia driver. Ideally this would be done in an
 	// uniform way after pivot_root but this is good enough and requires less
 	// code changes the nvidia code assumes it has access to the existing
@@ -496,10 +432,7 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 	// This way we can remove the temporary directory we created and "clean up"
 	// after ourselves nicely.
 	sc_must_snprintf(dst, sizeof dst, "%s/%s", SC_HOSTFS_DIR, scratch_dir);
-	debug("performing operation: umount %s", dst);
-	if (umount2(dst, 0) < 0) {
-		die("cannot perform operation: umount %s", dst);
-	}
+	sc_do_umount(dst, 0);
 	// Remove the scratch directory. Note that we are using the path that is
 	// based on the old root filesystem as after pivot_root we cannot guarantee
 	// what is present at the same location normally. (It is probably an empty
@@ -511,33 +444,20 @@ static void sc_bootstrap_mount_namespace(const struct sc_mount_config *config)
 	// Make the old root filesystem recursively slave. This way operations
 	// performed in this mount namespace will not propagate to the peer group.
 	// This is another essential part of the confinement system.
-	debug("performing operation: mount --make-rslave %s", SC_HOSTFS_DIR);
-	if (mount("none", SC_HOSTFS_DIR, NULL, MS_REC | MS_SLAVE, NULL) < 0) {
-		die("cannot perform operation: mount --make-rslave %s",
-		    SC_HOSTFS_DIR);
-	}
+	sc_do_mount("none", SC_HOSTFS_DIR, NULL, MS_REC | MS_SLAVE, NULL);
 	// Detach the redundant hostfs version of sysfs since it shows up in the
 	// mount table and software inspecting the mount table may become confused
 	// (eg, docker and LP:# 162601).
 	sc_must_snprintf(src, sizeof src, "%s/sys", SC_HOSTFS_DIR);
-	debug("performing operation: umount --lazy %s", src);
-	if (umount2(src, UMOUNT_NOFOLLOW | MNT_DETACH) < 0) {
-		die("cannot perform operation: umount --lazy %s", src);
-	}
+	sc_do_umount(src, UMOUNT_NOFOLLOW | MNT_DETACH);
 	// Detach the redundant hostfs version of /dev since it shows up in the
 	// mount table and software inspecting the mount table may become confused.
 	sc_must_snprintf(src, sizeof src, "%s/dev", SC_HOSTFS_DIR);
-	debug("performing operation: umount --lazy %s", src);
-	if (umount2(src, UMOUNT_NOFOLLOW | MNT_DETACH) < 0) {
-		die("cannot perform operation: umount --lazy %s", src);
-	}
+	sc_do_umount(src, UMOUNT_NOFOLLOW | MNT_DETACH);
 	// Detach the redundant hostfs version of /proc since it shows up in the
 	// mount table and software inspecting the mount table may become confused.
 	sc_must_snprintf(src, sizeof src, "%s/proc", SC_HOSTFS_DIR);
-	debug("performing operation: umount --lazy %s", src);
-	if (umount2(src, UMOUNT_NOFOLLOW | MNT_DETACH) < 0) {
-		die("cannot perform operation: umount --lazy %s", src);
-	}
+	sc_do_umount(src, UMOUNT_NOFOLLOW | MNT_DETACH);
 }
 
 /**
