@@ -24,8 +24,10 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"sort"
 	"time"
 
+	"github.com/snapcore/snapd/osutil"
 	"github.com/snapcore/snapd/overlord/assertstate"
 	"github.com/snapcore/snapd/overlord/snapstate"
 	"github.com/snapcore/snapd/overlord/state"
@@ -105,7 +107,7 @@ func localSnapInfo(st *state.State, name string) (aboutSnap, error) {
 }
 
 // allLocalSnapInfos returns the information about the all current snaps and their SnapStates.
-func allLocalSnapInfos(st *state.State, all bool) ([]aboutSnap, error) {
+func allLocalSnapInfos(st *state.State, all bool, wanted map[string]bool) ([]aboutSnap, error) {
 	st.Lock()
 	defer st.Unlock()
 
@@ -116,7 +118,10 @@ func allLocalSnapInfos(st *state.State, all bool) ([]aboutSnap, error) {
 	about := make([]aboutSnap, 0, len(snapStates))
 
 	var firstErr error
-	for _, snapst := range snapStates {
+	for name, snapst := range snapStates {
+		if len(wanted) > 0 && !wanted[name] {
+			continue
+		}
 		var aboutThis []aboutSnap
 		var info *snap.Info
 		var publisher string
@@ -154,9 +159,10 @@ func allLocalSnapInfos(st *state.State, all bool) ([]aboutSnap, error) {
 
 // appJSON contains the json for snap.AppInfo
 type appJSON struct {
-	Name    string   `json:"name"`
-	Daemon  string   `json:"daemon"`
-	Aliases []string `json:"aliases,omitempty"`
+	Name        string   `json:"name"`
+	Daemon      string   `json:"daemon"`
+	DesktopFile string   `json:"desktop-file,omitempty"`
+	Aliases     []string `json:"aliases,omitempty"`
 }
 
 // screenshotJSON contains the json for snap.ScreenshotInfo
@@ -173,12 +179,24 @@ func mapLocal(about aboutSnap) map[string]interface{} {
 		status = "active"
 	}
 
+	appNames := make([]string, 0, len(localSnap.Apps))
+	for appName := range localSnap.Apps {
+		appNames = append(appNames, appName)
+	}
+	sort.Strings(appNames)
 	apps := make([]appJSON, 0, len(localSnap.Apps))
-	for _, app := range localSnap.Apps {
+	for _, appName := range appNames {
+		app := localSnap.Apps[appName]
+		var installedDesktopFile string
+		if osutil.FileExists(app.DesktopFile()) {
+			installedDesktopFile = app.DesktopFile()
+		}
+
 		apps = append(apps, appJSON{
-			Name:    app.Name,
-			Daemon:  app.Daemon,
-			Aliases: app.Aliases,
+			Name:        app.Name,
+			Daemon:      app.Daemon,
+			DesktopFile: installedDesktopFile,
+			Aliases:     app.Aliases,
 		})
 	}
 
