@@ -24,7 +24,7 @@ package apparmor
 // It can be overridden for testing using MockTemplate().
 //
 // http://bazaar.launchpad.net/~ubuntu-security/ubuntu-core-security/trunk/view/head:/data/apparmor/templates/ubuntu-core/16.04/default
-var defaultTemplate = []byte(`
+var defaultTemplate = `
 # Description: Allows access to app-specific directories and basic runtime
 # Usage: common
 
@@ -94,6 +94,7 @@ var defaultTemplate = []byte(`
   /usr/share/terminfo/** r,
   /etc/inputrc r,
   # Common utilities for shell scripts
+  /{,usr/}bin/arch ixr,
   /{,usr/}bin/{,g,m}awk ixr,
   /{,usr/}bin/basename ixr,
   /{,usr/}bin/bunzip2 ixr,
@@ -132,6 +133,8 @@ var defaultTemplate = []byte(`
   /{,usr/}bin/infocmp ixr,
   /{,usr/}bin/kill ixr,
   /{,usr/}bin/ldd ixr,
+  /{usr/,}lib{,32,64}/ld{,32,64}-*.so ix,
+  /{usr/,}lib/@{multiarch}/ld{,32,64}-*.so ix,
   /{,usr/}bin/less{,file,pipe} ixr,
   /{,usr/}bin/ln ixr,
   /{,usr/}bin/line ixr,
@@ -341,7 +344,7 @@ var defaultTemplate = []byte(`
   # access in /dev/shm for shm_open() and files in subdirectories for open()
   /{dev,run}/shm/snap.@{SNAP_NAME}.** mrwlkix,
   # Also allow app-specific access for sem_open()
-  /{dev,run}/shm/sem.snap.@{SNAP_NAME}.* rwk,
+  /{dev,run}/shm/sem.snap.@{SNAP_NAME}.* mrwk,
 
   # Snap-specific XDG_RUNTIME_DIR that is based on the UID of the user
   owner /run/user/[0-9]*/snap.@{SNAP_NAME}/   rw,
@@ -387,9 +390,13 @@ var defaultTemplate = []byte(`
   /sys/class/ r,
   /sys/class/**/ r,
 
+  # Allow all snaps to chroot
+  capability sys_chroot,
+  /{,usr/}sbin/chroot ixr,
+
 ###SNIPPETS###
 }
-`)
+`
 
 // classicTemplate contains apparmor template used for snaps with classic
 // confinement. This template was Designed by jdstrand:
@@ -400,7 +407,7 @@ var defaultTemplate = []byte(`
 // label instead of 'unconfined'.
 //
 // It can be overridden for testing using MockClassicTemplate().
-var classicTemplate = []byte(`
+var classicTemplate = `
 #include <tunables/global>
 
 ###VAR###
@@ -426,16 +433,16 @@ var classicTemplate = []byte(`
 
 ###SNIPPETS###
 }
-`)
+`
 
 // classicJailmodeSnippet contains extra rules that allow snaps using classic
 // confinement, that were put in to jailmode, to execute by at least having
 // access to the core snap (e.g. for the dynamic linker and libc).
 
-var classicJailmodeSnippet = []byte(`
+var classicJailmodeSnippet = `
   # Read-only access to the core snap.
   @{INSTALL_DIR}/core/** r,
   # Read only access to the core snap to load libc from.
   # This is related to LP: #1666897
   @{INSTALL_DIR}/core/*/{,usr/}lib/@{multiarch}/{,**/}lib*.so* m,
-`)
+`
