@@ -27,20 +27,24 @@ var allInterfaces = []interfaces.Interface{
 	&BluezInterface{},
 	&BoolFileInterface{},
 	&BrowserSupportInterface{},
+	NewClassicSupportInterface(),
 	&ContentInterface{},
 	&DbusInterface{},
 	&DockerInterface{},
 	&DockerSupportInterface{},
+	&FramebufferInterface{},
 	&FwupdInterface{},
 	&GpioInterface{},
 	&HidrawInterface{},
 	&I2cInterface{},
 	&IioInterface{},
 	&IioPortsControlInterface{},
+	&JoystickInterface{},
 	&LocationControlInterface{},
 	&LocationObserveInterface{},
 	&LxdInterface{},
 	&LxdSupportInterface{},
+	&MaliitInterface{},
 	&MirInterface{},
 	&ModemManagerInterface{},
 	&MprisInterface{},
@@ -51,13 +55,21 @@ var allInterfaces = []interfaces.Interface{
 	&PppInterface{},
 	&PulseAudioInterface{},
 	&SerialPortInterface{},
+	&ThumbnailerServiceInterface{},
 	&TimeControlInterface{},
+	&Unity7Interface{},
 	&UDisks2Interface{},
+	&UbuntuDownloadManagerInterface{},
+	&Unity8Interface{},
 	&UpowerObserveInterface{},
+	&UhidInterface{},
+	NewAccountControlInterface(),
 	NewAlsaInterface(),
 	NewAvahiObserveInterface(),
+	NewAutopilotIntrospectionInterface(),
 	NewBluetoothControlInterface(),
 	NewCameraInterface(),
+	NewCoreSupportInterface(),
 	NewCupsControlInterface(),
 	NewDcdbasControlInterface(),
 	NewFirewallControlInterface(),
@@ -74,6 +86,7 @@ var allInterfaces = []interfaces.Interface{
 	NewNetworkControlInterface(),
 	NewNetworkInterface(),
 	NewNetworkObserveInterface(),
+	NewNetworkSetupControlInterface(),
 	NewNetworkSetupObserveInterface(),
 	NewOpenglInterface(),
 	NewOpenvSwitchInterface(),
@@ -90,7 +103,8 @@ var allInterfaces = []interfaces.Interface{
 	NewTimeserverControlInterface(),
 	NewTimezoneControlInterface(),
 	NewTpmInterface(),
-	NewUnity7Interface(),
+	NewUnity8CalendarInterface(),
+	NewUnity8ContactsInterface(),
 	NewX11Interface(),
 }
 
