@@ -38,32 +38,36 @@ func (s *AllSuite) TestInterfaces(c *C) {
 	c.Check(all, Contains, &builtin.DbusInterface{})
 	c.Check(all, Contains, &builtin.DockerInterface{})
 	c.Check(all, Contains, &builtin.DockerSupportInterface{})
-	c.Check(all, Contains, &builtin.FwupdInterface{})
+	c.Check(all, Contains, &builtin.FramebufferInterface{})
 	c.Check(all, Contains, &builtin.FwupdInterface{})
 	c.Check(all, Contains, &builtin.GpioInterface{})
 	c.Check(all, Contains, &builtin.HidrawInterface{})
 	c.Check(all, Contains, &builtin.I2cInterface{})
 	c.Check(all, Contains, &builtin.IioInterface{})
 	c.Check(all, Contains, &builtin.IioPortsControlInterface{})
+	c.Check(all, Contains, &builtin.JoystickInterface{})
 	c.Check(all, Contains, &builtin.LocationControlInterface{})
 	c.Check(all, Contains, &builtin.LocationObserveInterface{})
 	c.Check(all, Contains, &builtin.LxdSupportInterface{})
+	c.Check(all, Contains, &builtin.MaliitInterface{})
 	c.Check(all, Contains, &builtin.MirInterface{})
 	c.Check(all, Contains, &builtin.MprisInterface{})
 	c.Check(all, Contains, &builtin.PhysicalMemoryControlInterface{})
 	c.Check(all, Contains, &builtin.PhysicalMemoryObserveInterface{})
 	c.Check(all, Contains, &builtin.PulseAudioInterface{})
 	c.Check(all, Contains, &builtin.SerialPortInterface{})
-	c.Check(all, Contains, &builtin.ThumbnailerInterface{})
+	c.Check(all, Contains, &builtin.ThumbnailerServiceInterface{})
 	c.Check(all, Contains, &builtin.TimeControlInterface{})
 	c.Check(all, Contains, &builtin.UDisks2Interface{})
 	c.Check(all, Contains, &builtin.UbuntuDownloadManagerInterface{})
 	c.Check(all, Contains, &builtin.Unity8Interface{})
 	c.Check(all, Contains, &builtin.UpowerObserveInterface{})
 	c.Check(all, Contains, &builtin.UhidInterface{})
+	c.Check(all, Contains, &builtin.Unity7Interface{})
 	c.Check(all, DeepContains, builtin.NewAccountControlInterface())
 	c.Check(all, DeepContains, builtin.NewAlsaInterface())
 	c.Check(all, DeepContains, builtin.NewAvahiObserveInterface())
+	c.Check(all, DeepContains, builtin.NewAutopilotIntrospectionInterface())
 	c.Check(all, DeepContains, builtin.NewBluetoothControlInterface())
 	c.Check(all, DeepContains, builtin.NewCameraInterface())
 	c.Check(all, DeepContains, builtin.NewCupsControlInterface())
@@ -93,7 +97,6 @@ func (s *AllSuite) TestInterfaces(c *C) {
 	c.Check(all, DeepContains, builtin.NewTimeserverControlInterface())
 	c.Check(all, DeepContains, builtin.NewTimezoneControlInterface())
 	c.Check(all, DeepContains, builtin.NewTpmInterface())
-	c.Check(all, DeepContains, builtin.NewUnity7Interface())
 	c.Check(all, DeepContains, builtin.NewUnity8CalendarInterface())
 	c.Check(all, DeepContains, builtin.NewUnity8ContactsInterface())
 	c.Check(all, DeepContains, builtin.NewX11Interface())
