@@ -129,6 +129,7 @@ func (s *baseDeclSuite) TestAutoConnection(c *C) {
 	// own separate tests
 	snowflakes := map[string]bool{
 		"content":       true,
+		"core-support":  true,
 		"home":          true,
 		"lxd-support":   true,
 		"snapd-control": true,
@@ -136,18 +137,20 @@ func (s *baseDeclSuite) TestAutoConnection(c *C) {
 
 	// these simply auto-connect, anything else doesn't
 	autoconnect := map[string]bool{
-		"browser-support":        true,
-		"gsettings":              true,
-		"mir":                    true,
-		"network":                true,
-		"network-bind":           true,
-		"opengl":                 true,
-		"optical-drive":          true,
-		"pulseaudio":             true,
-		"screen-inhibit-control": true,
-		"unity7":                 true,
-		"upower-observe":         true,
-		"x11":                    true,
+		"browser-support":         true,
+		"gsettings":               true,
+		"mir":                     true,
+		"network":                 true,
+		"network-bind":            true,
+		"opengl":                  true,
+		"optical-drive":           true,
+		"pulseaudio":              true,
+		"screen-inhibit-control":  true,
+		"unity7":                  true,
+		"unity8":                  true,
+		"ubuntu-download-manager": true,
+		"upower-observe":          true,
+		"x11":                     true,
 	}
 
 	for _, iface := range all {
@@ -174,9 +177,10 @@ func (s *baseDeclSuite) TestAutoConnectPlugSlot(c *C) {
 	// these have more complex or in flux policies and have their
 	// own separate tests
 	snowflakes := map[string]bool{
-		"content":     true,
-		"home":        true,
-		"lxd-support": true,
+		"classic-support": true,
+		"content":         true,
+		"home":            true,
+		"lxd-support":     true,
 	}
 
 	for _, iface := range all {
@@ -218,11 +222,58 @@ plugs:
 }
 
 func (s *baseDeclSuite) TestAutoConnectionContent(c *C) {
-	// content will also depend for now AutoConnect(plug, slot)
 	// random snaps cannot connect with content
+	// (Sanitize* will now also block this)
 	cand := s.connectCand(c, "content", "", "")
 	err := cand.CheckAutoConnect()
 	c.Check(err, NotNil)
+
+	slotDecl1 := s.mockSnapDecl(c, "slot-snap", "slot-snap-id", "pub1", "")
+	plugDecl1 := s.mockSnapDecl(c, "plug-snap", "plug-snap-id", "pub1", "")
+	plugDecl2 := s.mockSnapDecl(c, "plug-snap", "plug-snap-id", "pub2", "")
+
+	// same publisher, same content
+	cand = s.connectCand(c, "stuff", `
+name: slot-snap
+slots:
+  stuff:
+    interface: content
+    content: mk1
+`, `
+name: plug-snap
+plugs:
+  stuff:
+    interface: content
+    content: mk1
+`)
+	cand.SlotSnapDeclaration = slotDecl1
+	cand.PlugSnapDeclaration = plugDecl1
+	err = cand.CheckAutoConnect()
+	c.Check(err, IsNil)
+
+	// different publisher, same content
+	cand.SlotSnapDeclaration = slotDecl1
+	cand.PlugSnapDeclaration = plugDecl2
+	err = cand.CheckAutoConnect()
+	c.Check(err, NotNil)
+
+	// same publisher, different content
+	cand = s.connectCand(c, "stuff", `name: slot-snap
+slots:
+  stuff:
+    interface: content
+    content: mk1
+`, `
+name: plug-snap
+plugs:
+  stuff:
+    interface: content
+    content: mk2
+`)
+	cand.SlotSnapDeclaration = slotDecl1
+	cand.PlugSnapDeclaration = plugDecl1
+	err = cand.CheckAutoConnect()
+	c.Check(err, NotNil)
 }
 
 func (s *baseDeclSuite) TestAutoConnectionLxdSupportOverride(c *C) {
@@ -294,6 +345,24 @@ plugs:
 	c.Check(err, IsNil)
 }
 
+func (s *baseDeclSuite) TestAutoConnectionClassicSupportOverride(c *C) {
+	cand := s.connectCand(c, "classic-support", "", "")
+	err := cand.CheckAutoConnect()
+	c.Check(err, NotNil)
+	c.Assert(err, ErrorMatches, "auto-connection denied by plug rule of interface \"classic-support\"")
+
+	plugsSlots := `
+plugs:
+  classic-support:
+    allow-auto-connection: true
+`
+
+	snapDecl := s.mockSnapDecl(c, "classic", "J60k4JY0HppjwOjW8dZdYc8obXKxujRu", "canonical", plugsSlots)
+	cand.PlugSnapDeclaration = snapDecl
+	err = cand.CheckAutoConnect()
+	c.Check(err, IsNil)
+}
+
 func (s *baseDeclSuite) TestAutoConnectionOverrideMultiple(c *C) {
 	plugsSlots := `
 plugs:
@@ -345,33 +414,54 @@ var (
 
 	slotInstallation = map[string][]string{
 		// other
-		"bluez":            {"app"},
-		"bool-file":        {"core", "gadget"},
-		"browser-support":  {"core"},
-		"content":          {"app", "gadget"},
-		"dbus":             {"app"},
-		"docker-support":   {"core"},
-		"fwupd":            {"app"},
-		"gpio":             {"core", "gadget"},
-		"hidraw":           {"core", "gadget"},
-		"i2c":              {"core", "gadget"},
-		"iio":              {"core", "gadget"},
-		"location-control": {"app"},
-		"location-observe": {"app"},
-		"lxd-support":      {"core"},
-		"mir":              {"app"},
-		"modem-manager":    {"app", "core"},
-		"mpris":            {"app"},
-		"network-manager":  {"app", "core"},
-		"ofono":            {"app", "core"},
-		"ppp":              {"core"},
-		"pulseaudio":       {"app", "core"},
-		"serial-port":      {"core", "gadget"},
-		"udisks2":          {"app"},
-		"upower-observe":   {"app", "core"},
+		"autopilot-introspection": {"core"},
+		"bluez":                   {"app"},
+		"bool-file":               {"core", "gadget"},
+		"browser-support":         {"core"},
+		"content":                 {"app", "gadget"},
+		"core-support":            {"core"},
+		"dbus":                    {"app"},
+		"docker-support":          {"core"},
+		"fwupd":                   {"app"},
+		"gpio":                    {"core", "gadget"},
+		"hidraw":                  {"core", "gadget"},
+		"i2c":                     {"core", "gadget"},
+		"iio":                     {"core", "gadget"},
+		"location-control":        {"app"},
+		"location-observe":        {"app"},
+		"lxd-support":             {"core"},
+		"maliit":                  {"app"},
+		"mir":                     {"app"},
+		"modem-manager":           {"app", "core"},
+		"mpris":                   {"app"},
+		"network-manager":         {"app", "core"},
+		"ofono":                   {"app", "core"},
+		"ppp":                     {"core"},
+		"pulseaudio":              {"app", "core"},
+		"serial-port":             {"core", "gadget"},
+		"thumbnailer-service":     {"app"},
+		"udisks2":                 {"app"},
+		"uhid":                    {"core"},
+		"unity8":                  {"app"},
+		"unity8-calendar":         {"app"},
+		"unity8-contacts":         {"app"},
+		"ubuntu-download-manager": {"app"},
+		"upower-observe":          {"app", "core"},
 		// snowflakes
-		"docker": nil,
-		"lxd":    nil,
+		"classic-support": nil,
+		"docker":          nil,
+		"lxd":             nil,
+	}
+
+	restrictedPlugInstallation = map[string][]string{
+		"core-support": {"core"},
+	}
+
+	snapTypeMap = map[string]snap.Type{
+		"core":   snap.TypeOS,
+		"app":    snap.TypeApp,
+		"kernel": snap.TypeKernel,
+		"gadget": snap.TypeGadget,
 	}
 )
 
@@ -385,13 +475,6 @@ func contains(l []string, s string) bool {
 }
 
 func (s *baseDeclSuite) TestSlotInstallation(c *C) {
-	typMap := map[string]snap.Type{
-		"core":   snap.TypeOS,
-		"app":    snap.TypeApp,
-		"kernel": snap.TypeKernel,
-		"gadget": snap.TypeGadget,
-	}
-
 	all := builtin.Interfaces()
 
 	for _, iface := range all {
@@ -406,7 +489,7 @@ func (s *baseDeclSuite) TestSlotInstallation(c *C) {
 			// snowflake needs to be tested specially
 			continue
 		}
-		for name, snapType := range typMap {
+		for name, snapType := range snapTypeMap {
 			ok := contains(types, name)
 			ic := s.installSlotCand(c, iface.Name(), snapType, ``)
 			slotInfo := ic.Snap.Slots[iface.Name()]
@@ -445,20 +528,40 @@ func (s *baseDeclSuite) TestPlugInstallation(c *C) {
 	all := builtin.Interfaces()
 
 	restricted := map[string]bool{
+		"classic-support":       true,
 		"docker-support":        true,
 		"kernel-module-control": true,
 		"lxd-support":           true,
 		"snapd-control":         true,
+		"unity8":                true,
 	}
 
 	for _, iface := range all {
-		ic := s.installPlugCand(c, iface.Name(), snap.TypeApp, ``)
-		err := ic.Check()
-		comm := Commentf("%s", iface.Name())
-		if restricted[iface.Name()] {
-			c.Check(err, NotNil, comm)
+		types, ok := restrictedPlugInstallation[iface.Name()]
+		// If plug installation is restricted to specific snap types we
+		// need to make sure this is really the case here. If that is not
+		// the case we continue as normal.
+		if ok {
+			for name, snapType := range snapTypeMap {
+				ok := contains(types, name)
+				ic := s.installPlugCand(c, iface.Name(), snapType, ``)
+				err := ic.Check()
+				comm := Commentf("%s by %s snap", iface.Name(), name)
+				if ok {
+					c.Check(err, IsNil, comm)
+				} else {
+					c.Check(err, NotNil, comm)
+				}
+			}
 		} else {
-			c.Check(err, IsNil, comm)
+			ic := s.installPlugCand(c, iface.Name(), snap.TypeApp, ``)
+			err := ic.Check()
+			comm := Commentf("%s", iface.Name())
+			if restricted[iface.Name()] {
+				c.Check(err, NotNil, comm)
+			} else {
+				c.Check(err, IsNil, comm)
+			}
 		}
 	}
 }
@@ -470,13 +573,19 @@ func (s *baseDeclSuite) TestConnection(c *C) {
 	// case-by-case basis
 	noconnect := map[string]bool{
 		"bluez":            true,
+		"content":          true,
 		"docker":           true,
 		"fwupd":            true,
 		"location-control": true,
 		"location-observe": true,
 		"lxd":              true,
+		"maliit":           true,
 		"mir":              true,
-		"udisks2":          true,
+		"thumbnailer-service":     true,
+		"udisks2":                 true,
+		"unity8-calendar":         true,
+		"unity8-contacts":         true,
+		"ubuntu-download-manager": true,
 	}
 
 	for _, iface := range all {
@@ -540,10 +649,13 @@ func (s *baseDeclSuite) TestSanity(c *C) {
 	// given how the rules work this can be delicate,
 	// listed here to make sure that was a conscious decision
 	bothSides := map[string]bool{
+		"classic-support":       true,
+		"core-support":          true,
 		"docker-support":        true,
 		"kernel-module-control": true,
 		"lxd-support":           true,
 		"snapd-control":         true,
+		"unity8":                true,
 	}
 
 	for _, iface := range all {
@@ -561,3 +673,59 @@ func (s *baseDeclSuite) TestSanity(c *C) {
 		}
 	}
 }
+
+func (s *baseDeclSuite) TestConnectionContent(c *C) {
+	// we let connect explicitly as long as content matches (or is absent on both sides)
+
+	// random (Sanitize* will now also block this)
+	cand := s.connectCand(c, "content", "", "")
+	err := cand.Check()
+	c.Check(err, NotNil)
+
+	slotDecl1 := s.mockSnapDecl(c, "slot-snap", "slot-snap-id", "pub1", "")
+	plugDecl1 := s.mockSnapDecl(c, "plug-snap", "plug-snap-id", "pub1", "")
+	plugDecl2 := s.mockSnapDecl(c, "plug-snap", "plug-snap-id", "pub2", "")
+
+	// same publisher, same content
+	cand = s.connectCand(c, "stuff", `name: slot-snap
+slots:
+  stuff:
+    interface: content
+    content: mk1
+`, `
+name: plug-snap
+plugs:
+  stuff:
+    interface: content
+    content: mk1
+`)
+	cand.SlotSnapDeclaration = slotDecl1
+	cand.PlugSnapDeclaration = plugDecl1
+	err = cand.Check()
+	c.Check(err, IsNil)
+
+	// different publisher, same content
+	cand.SlotSnapDeclaration = slotDecl1
+	cand.PlugSnapDeclaration = plugDecl2
+	err = cand.Check()
+	c.Check(err, IsNil)
+
+	// same publisher, different content
+	cand = s.connectCand(c, "stuff", `
+name: slot-snap
+slots:
+  stuff:
+    interface: content
+    content: mk1
+`, `
+name: plug-snap
+plugs:
+  stuff:
+    interface: content
+    content: mk2
+`)
+	cand.SlotSnapDeclaration = slotDecl1
+	cand.PlugSnapDeclaration = plugDecl1
+	err = cand.Check()
+	c.Check(err, NotNil)
+}
