@@ -20,13 +20,14 @@
 package builtin
 
 import (
-	"bytes"
 	"fmt"
 	"path/filepath"
 	"regexp"
 	"strings"
 
 	"github.com/snapcore/snapd/interfaces"
+	"github.com/snapcore/snapd/interfaces/apparmor"
+	"github.com/snapcore/snapd/interfaces/udev"
 )
 
 const iioConnectedPlugAppArmor = `
@@ -91,53 +92,38 @@ func (iface *IioInterface) SanitizePlug(plug *interfaces.Plug) error {
 	return nil
 }
 
-// Returns snippet granted on install
-func (iface *IioInterface) PermanentSlotSnippet(slot *interfaces.Slot, securitySystem interfaces.SecuritySystem) ([]byte, error) {
-	return nil, nil
-}
-
-// Getter for the security snippet specific to the plug
-func (iface *IioInterface) ConnectedPlugSnippet(plug *interfaces.Plug, slot *interfaces.Slot, securitySystem interfaces.SecuritySystem) ([]byte, error) {
+func (iface *IioInterface) AppArmorConnectedPlug(spec *apparmor.Specification, plug *interfaces.Plug, slot *interfaces.Slot) error {
 	path, pathOk := slot.Attrs["path"].(string)
 	if !pathOk {
-		return nil, nil
+		return nil
 	}
-	switch securitySystem {
-	case interfaces.SecurityAppArmor:
-		cleanedPath := filepath.Clean(path)
-		snippet := bytes.Replace([]byte(iioConnectedPlugAppArmor), []byte("###IIO_DEVICE_PATH###"), []byte(cleanedPath), -1)
 
-		// The path is already verified against a regular expression
-		// in SanitizeSlot so we can rely on its structure here and
-		// safely strip the '/dev/' prefix to get the actual name of
-		// the IIO device.
-		deviceName := strings.TrimPrefix(path, "/dev/")
-		snippet = bytes.Replace(snippet, []byte("###IIO_DEVICE_NAME###"), []byte(deviceName), -1)
+	cleanedPath := filepath.Clean(path)
+	snippet := strings.Replace(iioConnectedPlugAppArmor, "###IIO_DEVICE_PATH###", cleanedPath, -1)
 
-		return snippet, nil
+	// The path is already verified against a regular expression
+	// in SanitizeSlot so we can rely on its structure here and
+	// safely strip the '/dev/' prefix to get the actual name of
+	// the IIO device.
+	deviceName := strings.TrimPrefix(path, "/dev/")
+	snippet = strings.Replace(snippet, "###IIO_DEVICE_NAME###", deviceName, -1)
 
-	case interfaces.SecurityUDev:
-		var tagSnippet bytes.Buffer
-		const pathPrefix = "/dev/"
-		const udevRule = `KERNEL=="%s", TAG+="%s"`
-		for appName := range plug.Apps {
-			tag := udevSnapSecurityName(plug.Snap.Name(), appName)
-			tagSnippet.WriteString(fmt.Sprintf(udevRule, strings.TrimPrefix(path, pathPrefix), tag))
-			tagSnippet.WriteString("\n")
-		}
-		return tagSnippet.Bytes(), nil
-	}
-	return nil, nil
+	spec.AddSnippet(snippet)
+	return nil
 }
 
-// No extra permissions granted on connection
-func (iface *IioInterface) ConnectedSlotSnippet(plug *interfaces.Plug, slot *interfaces.Slot, securitySystem interfaces.SecuritySystem) ([]byte, error) {
-	return nil, nil
-}
-
-// No permissions granted to plug permanently
-func (iface *IioInterface) PermanentPlugSnippet(plug *interfaces.Plug, securitySystem interfaces.SecuritySystem) ([]byte, error) {
-	return nil, nil
+func (iface *IioInterface) UDevConnectedPlug(spec *udev.Specification, plug *interfaces.Plug, slot *interfaces.Slot) error {
+	path, pathOk := slot.Attrs["path"].(string)
+	if !pathOk {
+		return nil
+	}
+	const pathPrefix = "/dev/"
+	const udevRule = `KERNEL=="%s", TAG+="%s"`
+	for appName := range plug.Apps {
+		tag := udevSnapSecurityName(plug.Snap.Name(), appName)
+		spec.AddSnippet(fmt.Sprintf(udevRule, strings.TrimPrefix(path, pathPrefix), tag))
+	}
+	return nil
 }
 
 func (iface *IioInterface) AutoConnect(*interfaces.Plug, *interfaces.Slot) bool {
