@@ -656,77 +656,6 @@ func (r *Repository) Interfaces() *Interfaces {
 	return ifaces
 }
 
-// SecuritySnippetsForSnap collects all of the snippets of a given security
-// system that affect a given snap. The return value is indexed by app/hook
-// security tag within that snap.
-func (r *Repository) SecuritySnippetsForSnap(snapName string, securitySystem SecuritySystem) (map[string][][]byte, error) {
-	r.m.Lock()
-	defer r.m.Unlock()
-
-	return r.securitySnippetsForSnap(snapName, securitySystem)
-}
-
-func addSnippet(snapName, uniqueName string, apps map[string]*snap.AppInfo, hooks map[string]*snap.HookInfo, snippets map[string][][]byte, snippet []byte) {
-	if len(snippet) == 0 {
-		return
-	}
-	for appName := range apps {
-		securityTag := snap.AppSecurityTag(snapName, appName)
-		snippets[securityTag] = append(snippets[securityTag], snippet)
-	}
-	for hookName := range hooks {
-		securityTag := snap.HookSecurityTag(snapName, hookName)
-		snippets[securityTag] = append(snippets[securityTag], snippet)
-	}
-	if len(apps) == 0 && len(hooks) == 0 {
-		securityTag := snap.NoneSecurityTag(snapName, uniqueName)
-		snippets[securityTag] = append(snippets[securityTag], snippet)
-	}
-}
-
-func (r *Repository) securitySnippetsForSnap(snapName string, securitySystem SecuritySystem) (map[string][][]byte, error) {
-	var snippets = make(map[string][][]byte)
-	// Find all of the slots that affect this snap because of plug connection.
-	for _, slot := range r.slots[snapName] {
-		iface := r.ifaces[slot.Interface]
-		// Add the static snippet for the slot
-		snippet, err := iface.PermanentSlotSnippet(slot, securitySystem)
-		if err != nil {
-			return nil, err
-		}
-		addSnippet(snapName, slot.Name, slot.Apps, nil, snippets, snippet)
-
-		// Add connection-specific snippet specific to each plug
-		for plug := range r.slotPlugs[slot] {
-			snippet, err := iface.ConnectedSlotSnippet(plug, slot, securitySystem)
-			if err != nil {
-				return nil, err
-			}
-			addSnippet(snapName, slot.Name, slot.Apps, nil, snippets, snippet)
-		}
-	}
-	// Find all of the plugs that affect this snap because of slot connection
-	for _, plug := range r.plugs[snapName] {
-		iface := r.ifaces[plug.Interface]
-		// Add the static snippet for the plug
-		snippet, err := iface.PermanentPlugSnippet(plug, securitySystem)
-		if err != nil {
-			return nil, err
-		}
-		addSnippet(snapName, plug.Name, plug.Apps, plug.Hooks, snippets, snippet)
-
-		// Add connection-specific snippet specific to each slot
-		for slot := range r.plugSlots[plug] {
-			snippet, err := iface.ConnectedPlugSnippet(plug, slot, securitySystem)
-			if err != nil {
-				return nil, err
-			}
-			addSnippet(snapName, plug.Name, plug.Apps, plug.Hooks, snippets, snippet)
-		}
-	}
-	return snippets, nil
-}
-
 // SnapSpecification returns the specification of a given snap in a given security system.
 func (r *Repository) SnapSpecification(securitySystem SecuritySystem, snapName string) (Specification, error) {
 	r.m.Lock()
@@ -833,6 +762,11 @@ func (r *Repository) AddSnap(snapInfo *snap.Info) error {
 			bad.issues[plugName] = "unknown interface"
 			continue
 		}
+		// Reject plug with invalid name
+		if err := ValidateName(plugName); err != nil {
+			bad.issues[plugName] = err.Error()
+			continue
+		}
 		plug := &Plug{PlugInfo: plugInfo}
 		if err := iface.SanitizePlug(plug); err != nil {
 			bad.issues[plugName] = err.Error()
@@ -850,6 +784,11 @@ func (r *Repository) AddSnap(snapInfo *snap.Info) error {
 			bad.issues[slotName] = "unknown interface"
 			continue
 		}
+		// Reject slot with invalid name
+		if err := ValidateName(slotName); err != nil {
+			bad.issues[slotName] = err.Error()
+			continue
+		}
 		slot := &Slot{SlotInfo: slotInfo}
 		if err := iface.SanitizeSlot(slot); err != nil {
 			bad.issues[slotName] = err.Error()
