@@ -21,6 +21,7 @@ package snapstate_test
 
 import (
 	"fmt"
+	"sort"
 
 	. "gopkg.in/check.v1"
 	"gopkg.in/tomb.v2"
@@ -674,7 +675,7 @@ var statusesMatrix = []struct {
 	{"alias1", "", "reset", "", "-"},
 	{"alias1", "enabled", "reset", "", "rm"},
 	{"alias1", "disabled", "reset", "", "-"},
-	{"alias1", "auto", "reset", "auto", "-"},
+	{"alias1", "auto", "reset", "", "rm"}, // used to retire auto-aliases
 	{"alias5", "", "reset", "auto", "add"},
 	{"alias5", "enabled", "reset", "auto", "-"},
 	{"alias5", "disabled", "reset", "auto", "add"},
@@ -682,11 +683,11 @@ var statusesMatrix = []struct {
 	{"alias1gone", "", "reset", "", "-"},
 	{"alias1gone", "enabled", "reset", "", "-"},
 	{"alias1gone", "disabled", "reset", "", "-"},
-	{"alias1gone", "auto", "reset", "auto", "-"},
+	{"alias1gone", "auto", "reset", "", "-"},
 	{"alias5gone", "", "reset", "", "-"},
 	{"alias5gone", "enabled", "reset", "", "-"},
 	{"alias5gone", "disabled", "reset", "", "-"},
-	{"alias5gone", "auto", "reset", "auto", "-"},
+	{"alias5gone", "auto", "reset", "", "-"},
 }
 
 func (s *snapmgrTestSuite) TestAliasMatrixRunThrough(c *C) {
@@ -705,9 +706,9 @@ func (s *snapmgrTestSuite) TestAliasMatrixRunThrough(c *C) {
 	// alias5 is an auto-alias
 	// alias1gone is a non auto-alias and doesn't have an entry in the current snap revision anymore
 	// alias5gone is an auto-alias and doesn't have an entry in the current snap revision anymore
-	snapstate.AutoAliases = func(st *state.State, info *snap.Info) ([]string, error) {
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
 		c.Check(info.Name(), Equals, "alias-snap")
-		return []string{"alias5", "alias5lost"}, nil
+		return map[string]string{"alias5": "cmd5", "alias5gone": "cmd5gone"}, nil
 	}
 	cmds := map[string]string{
 		"alias1": "cmd1",
@@ -750,7 +751,7 @@ func (s *snapmgrTestSuite) TestAliasMatrixRunThrough(c *C) {
 		c.Assert(chg.Status(), Equals, state.DoneStatus, Commentf("%#v: %v", scenario, chg.Err()))
 		var aliases []*backend.Alias
 		var rmAliases []*backend.Alias
-		beAlias := &backend.Alias{scenAlias, fmt.Sprintf("alias-snap.%s", cmds[scenAlias])}
+		beAlias := &backend.Alias{Name: scenAlias, Target: fmt.Sprintf("alias-snap.%s", cmds[scenAlias])}
 		switch scenario.mutation {
 		case "-":
 		case "add":
@@ -769,7 +770,7 @@ func (s *snapmgrTestSuite) TestAliasMatrixRunThrough(c *C) {
 		}
 		// start with an easier-to-read error if this fails:
 		c.Assert(s.fakeBackend.ops.Ops(), DeepEquals, expected.Ops(), comm)
-		c.Assert(s.fakeBackend.ops, DeepEquals, expected, comm)
+		c.Check(s.fakeBackend.ops, DeepEquals, expected, comm)
 
 		var allAliases map[string]map[string]string
 		err = s.state.Get("aliases", &allAliases)
@@ -800,11 +801,11 @@ func (s *snapmgrTestSuite) TestAliasMatrixTotalUndoRunThrough(c *C) {
 
 	// alias1 is a non auto-alias
 	// alias5 is an auto-alias
-	// alias1lost is a non auto-alias and doesn't have an entry in the snap anymore
-	// alias5lost is an auto-alias and doesn't have an entry in the snap any
-	snapstate.AutoAliases = func(st *state.State, info *snap.Info) ([]string, error) {
+	// alias1gone is a non auto-alias and doesn't have an entry in the snap anymore
+	// alias5gone is an auto-alias and doesn't have an entry in the snap any
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
 		c.Check(info.Name(), Equals, "alias-snap")
-		return []string{"alias5", "alias5lost"}, nil
+		return map[string]string{"alias5": "cmd5", "alias5gone": "cmd5gone"}, nil
 	}
 	cmds := map[string]string{
 		"alias1": "cmd1",
@@ -858,7 +859,7 @@ func (s *snapmgrTestSuite) TestAliasMatrixTotalUndoRunThrough(c *C) {
 		c.Assert(chg.Status(), Equals, state.ErrorStatus, Commentf("%#v: %v", scenario, chg.Err()))
 		var aliases []*backend.Alias
 		var rmAliases []*backend.Alias
-		beAlias := &backend.Alias{scenAlias, fmt.Sprintf("alias-snap.%s", cmds[scenAlias])}
+		beAlias := &backend.Alias{Name: scenAlias, Target: fmt.Sprintf("alias-snap.%s", cmds[scenAlias])}
 		switch scenario.mutation {
 		case "-":
 		case "add":
@@ -890,7 +891,164 @@ func (s *snapmgrTestSuite) TestAliasMatrixTotalUndoRunThrough(c *C) {
 		}
 		// start with an easier-to-read error if this fails:
 		c.Assert(s.fakeBackend.ops.Ops(), DeepEquals, expected.Ops(), comm)
-		c.Assert(s.fakeBackend.ops, DeepEquals, expected, comm)
+		c.Check(s.fakeBackend.ops, DeepEquals, expected, comm)
+
+		var allAliases map[string]map[string]string
+		err = s.state.Get("aliases", &allAliases)
+		c.Assert(err, IsNil)
+		if scenario.beforeStatus != "" {
+			c.Check(allAliases, DeepEquals, map[string]map[string]string{
+				"alias-snap": {scenAlias: scenario.beforeStatus},
+			}, comm)
+		} else {
+			c.Check(allAliases, HasLen, 0, comm)
+		}
+
+		s.fakeBackend.ops = nil
+	}
+}
+
+func (s *snapmgrTestSuite) TestDisabledSnapResetAliasesRunThrough(c *C) {
+	s.state.Lock()
+	defer s.state.Unlock()
+
+	snapstate.Set(s.state, "alias-snap", &snapstate.SnapState{
+		Sequence: []*snap.SideInfo{
+			{RealName: "alias-snap", Revision: snap.R(11)},
+		},
+		Current: snap.R(11),
+		Active:  false,
+	})
+
+	// alias1 is a non auto-alias
+	// alias5 is an auto-alias
+	// alias1gone is a non auto-alias and doesn't have an entry in the current snap revision anymore
+	// alias5gone is an auto-alias and doesn't have an entry in the current snap revision anymore
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
+		c.Check(info.Name(), Equals, "alias-snap")
+		return map[string]string{"alias5": "cmd5", "alias5gone": "cmd5gone"}, nil
+	}
+
+	defer s.snapmgr.Stop()
+	for _, scenario := range statusesMatrix {
+		if scenario.action != "reset" {
+			// we reuse the scenarios but here want to test only reset i.e. ResetAliases for the disabled snap case (the other actions are still unsupported for disabled snaps)
+			continue
+		}
+
+		scenAlias := scenario.alias
+		if scenario.beforeStatus != "" {
+			s.state.Set("aliases", map[string]map[string]string{
+				"alias-snap": {
+					scenAlias: scenario.beforeStatus,
+				},
+			})
+		} else {
+			s.state.Set("aliases", nil)
+		}
+
+		chg := s.state.NewChange("scenario", "...")
+		var err error
+		var ts *state.TaskSet
+		targets := []string{scenAlias}
+		ts, err = snapstate.ResetAliases(s.state, "alias-snap", targets)
+		c.Assert(err, IsNil)
+
+		chg.AddAll(ts)
+
+		s.state.Unlock()
+		s.settle()
+		s.state.Lock()
+
+		c.Assert(chg.Status(), Equals, state.DoneStatus, Commentf("%#v: %v", scenario, chg.Err()))
+
+		comm := Commentf("%#v", scenario)
+		// no mutation
+		c.Check(s.fakeBackend.ops, HasLen, 0, comm)
+
+		var allAliases map[string]map[string]string
+		err = s.state.Get("aliases", &allAliases)
+		c.Assert(err, IsNil)
+		if scenario.status != "" {
+			c.Check(allAliases, DeepEquals, map[string]map[string]string{
+				"alias-snap": {scenAlias: scenario.status},
+			}, comm)
+		} else {
+			c.Check(allAliases, HasLen, 0, comm)
+		}
+
+		s.fakeBackend.ops = nil
+	}
+}
+
+func (s *snapmgrTestSuite) TestDisabledSnapResetAliasesTotalUndoRunThrough(c *C) {
+	s.state.Lock()
+	defer s.state.Unlock()
+
+	snapstate.Set(s.state, "alias-snap", &snapstate.SnapState{
+		Sequence: []*snap.SideInfo{
+			{RealName: "alias-snap", Revision: snap.R(11)},
+		},
+		Current: snap.R(11),
+		Active:  false,
+	})
+
+	// alias1 is a non auto-alias
+	// alias5 is an auto-alias
+	// alias1gone is a non auto-alias and doesn't have an entry in the snap anymore
+	// alias5gone is an auto-alias and doesn't have an entry in the snap any
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
+		c.Check(info.Name(), Equals, "alias-snap")
+		return map[string]string{"alias5": "cmd5", "alias5gone": "cmd5gone"}, nil
+	}
+
+	defer s.snapmgr.Stop()
+	for _, scenario := range statusesMatrix {
+		if scenario.action != "reset" {
+			// we reuse the scenarios but here want to test only reset i.e. ResetAliases for the disabled snap case (the other actions are still unsupported for disabled snaps)
+			continue
+		}
+
+		scenAlias := scenario.alias
+		if scenario.beforeStatus != "" {
+			s.state.Set("aliases", map[string]map[string]string{
+				"alias-snap": {
+					scenAlias: scenario.beforeStatus,
+				},
+			})
+		} else {
+			s.state.Set("aliases", nil)
+		}
+
+		chg := s.state.NewChange("scenario", "...")
+		var err error
+		var ts *state.TaskSet
+		targets := []string{scenAlias}
+
+		ts, err = snapstate.ResetAliases(s.state, "alias-snap", targets)
+		c.Assert(err, IsNil)
+
+		chg.AddAll(ts)
+
+		tasks := ts.Tasks()
+		last := tasks[len(tasks)-1]
+
+		terr := s.state.NewTask("error-trigger", "provoking total undo")
+		terr.WaitFor(last)
+		chg.AddTask(terr)
+
+		s.state.Unlock()
+		for i := 0; i < 3; i++ {
+			s.snapmgr.Ensure()
+			s.snapmgr.Wait()
+		}
+		s.state.Lock()
+
+		c.Assert(chg.Status(), Equals, state.ErrorStatus, Commentf("%#v: %v", scenario, chg.Err()))
+
+		comm := Commentf("%#v", scenario)
+		// no mutation
+		c.Check(s.fakeBackend.ops, HasLen, 0, comm)
 
 		var allAliases map[string]map[string]string
 		err = s.state.Get("aliases", &allAliases)
@@ -1016,9 +1174,14 @@ func (s *snapmgrTestSuite) TestUnliasTotalUndoRunThroughAliasConflict(c *C) {
 }
 
 func (s *snapmgrTestSuite) TestAutoAliasesDelta(c *C) {
-	snapstate.AutoAliases = func(st *state.State, info *snap.Info) ([]string, error) {
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
 		c.Check(info.Name(), Equals, "alias-snap")
-		return []string{"alias1", "alias2", "alias4", "alias5"}, nil
+		return map[string]string{
+			"alias1": "cmd1",
+			"alias2": "cmd2",
+			"alias4": "cmd4",
+			"alias5": "cmd5",
+		}, nil
 	}
 
 	s.state.Lock()
@@ -1043,9 +1206,10 @@ func (s *snapmgrTestSuite) TestAutoAliasesDelta(c *C) {
 	new, retired, err := snapstate.AutoAliasesDelta(s.state, []string{"alias-snap"})
 	c.Assert(err, IsNil)
 
-	c.Check(new, DeepEquals, map[string][]string{
-		"alias-snap": {"alias4", "alias5"},
-	})
+	c.Check(new, HasLen, 1)
+	which := new["alias-snap"]
+	sort.Strings(which)
+	c.Check(which, DeepEquals, []string{"alias4", "alias5"})
 
 	c.Check(retired, DeepEquals, map[string][]string{
 		"alias-snap": {"alias3"},
@@ -1054,10 +1218,15 @@ func (s *snapmgrTestSuite) TestAutoAliasesDelta(c *C) {
 
 func (s *snapmgrTestSuite) TestAutoAliasesDeltaAll(c *C) {
 	seen := make(map[string]bool)
-	snapstate.AutoAliases = func(st *state.State, info *snap.Info) ([]string, error) {
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
 		seen[info.Name()] = true
 		if info.Name() == "alias-snap" {
-			return []string{"alias1", "alias2", "alias4", "alias5"}, nil
+			return map[string]string{
+				"alias1": "cmd1",
+				"alias2": "cmd2",
+				"alias4": "cmd4",
+				"alias5": "cmd5",
+			}, nil
 		}
 		return nil, nil
 	}
@@ -1083,9 +1252,10 @@ func (s *snapmgrTestSuite) TestAutoAliasesDeltaAll(c *C) {
 	new, retired, err := snapstate.AutoAliasesDelta(s.state, nil)
 	c.Assert(err, IsNil)
 
-	c.Check(new, DeepEquals, map[string][]string{
-		"alias-snap": {"alias1", "alias2", "alias4", "alias5"},
-	})
+	c.Check(new, HasLen, 1)
+	which := new["alias-snap"]
+	sort.Strings(which)
+	c.Check(which, DeepEquals, []string{"alias1", "alias2", "alias4", "alias5"})
 
 	c.Check(retired, HasLen, 0)
 
@@ -1099,9 +1269,14 @@ func (s *snapmgrTestSuite) TestDoSetAutoAliases(c *C) {
 	s.state.Lock()
 	defer s.state.Unlock()
 
-	snapstate.AutoAliases = func(st *state.State, info *snap.Info) ([]string, error) {
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
 		c.Check(info.Name(), Equals, "alias-snap")
-		return []string{"alias1", "alias2", "alias4", "alias5"}, nil
+		return map[string]string{
+			"alias1": "cmd1",
+			"alias2": "cmd2",
+			"alias4": "cmd4",
+			"alias5": "cmd5",
+		}, nil
 	}
 
 	snapstate.Set(s.state, "alias-snap", &snapstate.SnapState{
@@ -1154,9 +1329,14 @@ func (s *snapmgrTestSuite) TestDoUndoSetAutoAliases(c *C) {
 	s.state.Lock()
 	defer s.state.Unlock()
 
-	snapstate.AutoAliases = func(st *state.State, info *snap.Info) ([]string, error) {
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
 		c.Check(info.Name(), Equals, "alias-snap")
-		return []string{"alias1", "alias2", "alias4", "alias5"}, nil
+		return map[string]string{
+			"alias1": "cmd1",
+			"alias2": "cmd2",
+			"alias4": "cmd4",
+			"alias5": "cmd5",
+		}, nil
 	}
 
 	snapstate.Set(s.state, "alias-snap", &snapstate.SnapState{
@@ -1215,9 +1395,14 @@ func (s *snapmgrTestSuite) TestDoSetAutoAliasesConflict(c *C) {
 	s.state.Lock()
 	defer s.state.Unlock()
 
-	snapstate.AutoAliases = func(st *state.State, info *snap.Info) ([]string, error) {
+	snapstate.AutoAliases = func(st *state.State, info *snap.Info) (map[string]string, error) {
 		c.Check(info.Name(), Equals, "alias-snap")
-		return []string{"alias1", "alias2", "alias4", "alias5"}, nil
+		return map[string]string{
+			"alias1": "cmd1",
+			"alias2": "cmd2",
+			"alias4": "cmd4",
+			"alias5": "cmd5",
+		}, nil
 	}
 
 	snapstate.Set(s.state, "alias-snap", &snapstate.SnapState{
@@ -1256,3 +1441,62 @@ func (s *snapmgrTestSuite) TestDoSetAutoAliasesConflict(c *C) {
 	c.Check(t.Status(), Equals, state.ErrorStatus, Commentf("%v", chg.Err()))
 	c.Check(chg.Err(), ErrorMatches, `(?s).*cannot enable alias "alias4" for "alias-snap", already enabled for "other-snap".*`)
 }
+
+func (s *snapmgrTestSuite) TestAliases(c *C) {
+	s.state.Lock()
+	defer s.state.Unlock()
+
+	// nothing
+	aliases, err := snapstate.Aliases(s.state)
+	c.Assert(err, IsNil)
+	c.Check(aliases, HasLen, 0)
+
+	// snaps with aliases
+	snapstate.Set(s.state, "alias-snap", &snapstate.SnapState{
+		Sequence: []*snap.SideInfo{
+			{RealName: "alias-snap", Revision: snap.R(11)},
+		},
+		Current: snap.R(11),
+		Active:  true,
+	})
+
+	snapstate.Set(s.state, "alias-snap2", &snapstate.SnapState{
+		Sequence: []*snap.SideInfo{
+			{RealName: "alias-snap2", Revision: snap.R(12)},
+		},
+		Current: snap.R(12),
+		Active:  true,
+	})
+
+	snapstate.Set(s.state, "other-snap", &snapstate.SnapState{
+		Sequence: []*snap.SideInfo{
+			{RealName: "other-snap", Revision: snap.R(2)},
+		},
+		Current: snap.R(2),
+		Active:  true,
+	})
+
+	s.state.Set("aliases", map[string]map[string]string{
+		"alias-snap": {
+			"alias1": "enabled",
+			"alias5": "auto",
+			"alias3": "disabled",
+		},
+		"alias-snap2": {
+			"alias2": "enabled",
+		},
+	})
+
+	aliases, err = snapstate.Aliases(s.state)
+	c.Assert(err, IsNil)
+	c.Check(aliases, DeepEquals, map[string]map[string]string{
+		"alias-snap": {
+			"alias1": "enabled",
+			"alias5": "auto",
+			"alias3": "disabled",
+		},
+		"alias-snap2": {
+			"alias2": "enabled",
+		},
+	})
+}
