@@ -21,6 +21,7 @@ package snapstate
 
 import (
 	"errors"
+	"time"
 
 	"gopkg.in/tomb.v2"
 
@@ -95,6 +96,17 @@ func MockErrtrackerReport(mock func(string, string, string, map[string]string) (
 	return func() { errtrackerReport = prev }
 }
 
+func MockRefreshInterval(newMinRefreshInterval, newRefreshRandomness time.Duration) (restore func()) {
+	prevMinRefreshInterval := minRefreshInterval
+	prevDefaultRefreshRandomness := defaultRefreshRandomness
+	minRefreshInterval = newMinRefreshInterval
+	defaultRefreshRandomness = newRefreshRandomness
+	return func() {
+		minRefreshInterval = prevMinRefreshInterval
+		defaultRefreshRandomness = prevDefaultRefreshRandomness
+	}
+}
+
 var (
 	CheckSnap            = checkSnap
 	CanRemove            = canRemove
@@ -106,3 +118,11 @@ var (
 func PreviousSideInfo(snapst *SnapState) *snap.SideInfo {
 	return snapst.previousSideInfo()
 }
+
+// aliases v2
+var (
+	ApplyAliasesChange    = applyAliasesChange
+	AutoAliasesDeltaV2    = autoAliasesDeltaV2
+	RefreshAliases        = refreshAliases
+	CheckAliasesConflicts = checkAliasesConflicts
+)
