@@ -26,6 +26,7 @@ import (
 
 	"gopkg.in/yaml.v2"
 
+	"github.com/snapcore/snapd/strutil"
 	"github.com/snapcore/snapd/systemd"
 	"github.com/snapcore/snapd/timeout"
 )
@@ -42,7 +43,7 @@ type snapYaml struct {
 	LicenseVersion   string                 `yaml:"license-version,omitempty"`
 	Epoch            string                 `yaml:"epoch,omitempty"`
 	Confinement      ConfinementType        `yaml:"confinement,omitempty"`
-	Environment      map[string]string      `yaml:"environment,omitempty"`
+	Environment      strutil.OrderedMap     `yaml:"environment,omitempty"`
 	Plugs            map[string]interface{} `yaml:"plugs,omitempty"`
 	Slots            map[string]interface{} `yaml:"slots,omitempty"`
 	Apps             map[string]appYaml     `yaml:"apps,omitempty"`
@@ -67,7 +68,7 @@ type appYaml struct {
 
 	BusName string `yaml:"bus-name,omitempty"`
 
-	Environment map[string]string `yaml:"environment,omitempty"`
+	Environment strutil.OrderedMap `yaml:"environment,omitempty"`
 }
 
 type hookYaml struct {
@@ -83,7 +84,6 @@ func InfoFromSnapYaml(yamlData []byte) (*Info, error) {
 	}
 
 	snap := infoSkeletonFromSnapYaml(y)
-	setEnvironmentFromSnapYaml(y, snap)
 
 	// Collect top-level definitions of plugs and slots
 	if err := setPlugsFromSnapYaml(y, snap); err != nil {
@@ -118,6 +118,9 @@ func InfoFromSnapYaml(yamlData []byte) (*Info, error) {
 	// Bind unbound slots to all apps
 	bindUnboundSlots(globalSlotNames, snap)
 
+	// Rename specific plugs on the core snap.
+	snap.renameClashingCorePlugs()
+
 	// FIXME: validation of the fields
 	return snap, nil
 }
@@ -169,12 +172,6 @@ func infoSkeletonFromSnapYaml(y snapYaml) *Info {
 	return snap
 }
 
-func setEnvironmentFromSnapYaml(y snapYaml, snap *Info) {
-	for k, v := range y.Environment {
-		snap.Environment[k] = v
-	}
-}
-
 func setPlugsFromSnapYaml(y snapYaml, snap *Info) error {
 	for name, data := range y.Plugs {
 		iface, label, attrs, err := convertToSlotOrPlugData("plug", name, data)
