@@ -300,6 +300,7 @@ Description=Mount unit for foo
 What=%s
 Where=/apps/foo/1.0
 Type=squashfs
+Options=nodev
 
 [Install]
 WantedBy=multi-user.target
@@ -322,7 +323,7 @@ Description=Mount unit for foodir
 What=%s
 Where=/apps/foo/1.0
 Type=none
-Options=bind
+Options=nodev,bind
 
 [Install]
 WantedBy=multi-user.target
@@ -380,7 +381,7 @@ Description=Mount unit for foo
 What=%s
 Where=/apps/foo/1.0
 Type=fuse.squashfuse
-Options=ro,allow_other
+Options=nodev,ro,allow_other
 
 [Install]
 WantedBy=multi-user.target
@@ -418,6 +419,7 @@ Description=Mount unit for foo
 What=%s
 Where=/apps/foo/1.0
 Type=squashfs
+Options=nodev
 
 [Install]
 WantedBy=multi-user.target
